from _typeshed import Incomplete as Incomplete

def func(*args, **kwargs) -> Incomplete: ...
def callback(*args, **kwargs) -> Incomplete: ...
def as_bytearray(*args, **kwargs) -> Incomplete: ...
def open(*args, **kwargs) -> Incomplete: ...
